==> truffle-api-1.0.0-rc9.jar: module-info.java <==
module org.graalvm.truffle {
    requires java.base;
    requires static java.desktop;
    requires java.logging;
    requires jdk.unsupported;
    requires transitive org.graalvm.sdk;
    exports com.oracle.truffle.api;
    exports com.oracle.truffle.api.debug;
    exports com.oracle.truffle.api.dsl;
    exports com.oracle.truffle.api.frame;
    exports com.oracle.truffle.api.impl;
    exports com.oracle.truffle.api.instrumentation;
    exports com.oracle.truffle.api.interop;
    exports com.oracle.truffle.api.nodes;
    exports com.oracle.truffle.api.object;
    exports com.oracle.truffle.api.object.dsl;
    exports com.oracle.truffle.api.profiles;
    exports com.oracle.truffle.api.source;
    exports com.oracle.truffle.api.utilities;
    exports com.oracle.truffle.object;
    exports com.oracle.truffle.object.basic;
    uses com.oracle.truffle.api.TruffleRuntimeAccess;
    uses com.oracle.truffle.api.impl.TruffleLocator;
    uses com.oracle.truffle.api.object.LayoutFactory;
    uses java.nio.file.spi.FileTypeDetector;
    provides com.oracle.truffle.api.object.LayoutFactory with com.oracle.truffle.object.basic.DefaultLayoutFactory;
    provides org.graalvm.polyglot.impl.AbstractPolyglotImpl with com.oracle.truffle.polyglot.PolyglotImpl;
    // conceals: com.oracle.truffle.api.debug.impl
    // conceals: com.oracle.truffle.api.dsl.internal
    // conceals: com.oracle.truffle.api.interop.impl
    // conceals: com.oracle.truffle.polyglot
    // jarpath: /home/gmdubosc/Dev/Graal/graal/truffle/mxbuild/dists/jdk11/truffle-api.jar
    // dist: TRUFFLE_API
    // modulepath: org.graalvm.sdk
}

==> truffle-api-19.2.0.jar: module-info.java <==
module org.graalvm.truffle {
    requires java.base;
    requires static java.desktop;
    requires java.logging;
    requires jdk.unsupported;
    requires transitive org.graalvm.sdk;
    exports com.oracle.truffle.api;
    exports com.oracle.truffle.api.debug;
    exports com.oracle.truffle.api.dsl;
    exports com.oracle.truffle.api.frame;
    exports com.oracle.truffle.api.impl;
    exports com.oracle.truffle.api.instrumentation;
    exports com.oracle.truffle.api.interop;
    exports com.oracle.truffle.api.io;
    exports com.oracle.truffle.api.library;
    exports com.oracle.truffle.api.nodes;
    exports com.oracle.truffle.api.object;
    exports com.oracle.truffle.api.object.dsl;
    exports com.oracle.truffle.api.profiles;
    exports com.oracle.truffle.api.source;
    exports com.oracle.truffle.api.utilities;
    exports com.oracle.truffle.object;
    exports com.oracle.truffle.object.basic;
    uses com.oracle.truffle.api.TruffleRuntimeAccess;
    uses com.oracle.truffle.api.impl.TruffleLocator;
    uses com.oracle.truffle.api.object.LayoutFactory;
    uses java.nio.file.spi.FileTypeDetector;
    provides com.oracle.truffle.api.object.LayoutFactory with com.oracle.truffle.object.basic.DefaultLayoutFactory;
    provides org.graalvm.polyglot.impl.AbstractPolyglotImpl with com.oracle.truffle.polyglot.PolyglotImpl;
    // conceals: com.oracle.truffle.api.debug.impl
    // conceals: com.oracle.truffle.api.interop.impl
    // conceals: com.oracle.truffle.polyglot
    // jarpath: /graalvm/graal/truffle/mxbuild/dists/jdk11/truffle-api.jar
    // dist: TRUFFLE_API
    // modulepath: org.graalvm.sdk
}
